# Contributing guidelines

Any contribution is appreciated! You might want to:

* Fix spelling errors
* Improve documentation
* Add tests
* Add new features
* Fix bugs

> Note: Feel free to point out any obvious flaw I might have made, I'm new to this and welcome any feedback or help.

## How can I contribute?

* Use [issues](https://github.com/KunalGehlot/logEZ/issues) to report bugs and features
    - If you report a bug in the results for a particular pdf, include that pdf. This allows others to replicate the
     issue. 
* Fix issues by [creating pull requests](https://help.github.com/en/articles/creating-a-pull-request).
* Help others by sharing your thoughts in comments on issues and pull requests.